@@ -1,6 +1,6 @@
 /* repint_subrs.h -- library-local prototypes
    Copyright (C) 1993, 1994 John Harper <john@dcs.warwick.ac.uk>
-   $Id: repint_subrs.h,v 1.45 2001/06/13 01:32:43 jsh Exp $
+   $Id: repint_subrs.h,v 1.49 2001/09/14 14:37:33 jsh Exp $
 
    This file is part of Jade.
 
@@ -90,6 +90,13 @@ extern repv rep_parse_number (char *buf, u_int len, u_int radix,
 			      int sign, u_int type);
 extern void rep_numbers_init (void);
 
+/* from origin.c */
+extern rep_bool rep_record_origins;
+extern void rep_record_origin (repv form, repv stream, long start_line);
+extern repv Flexical_origin (repv form);
+extern void rep_mark_origins (void);
+extern void rep_origin_init (void);
+
 /* from regsub.c */
 extern void rep_default_regsub(int, rep_regsubs *, char *, char *, void *);
 extern int rep_default_regsublen(int, rep_regsubs *, char *, void *);
@@ -142,6 +149,13 @@ extern void rep_values_init(void);
 extern void rep_values_kill (void);
 extern void rep_dumped_init(char *file);
 
+/* from weak-refs.c */
+extern repv Fmake_weak_ref (repv value);
+extern repv Fweak_ref (repv ref);
+extern repv Fweak_ref_set (repv ref, repv value);
+extern void rep_scan_weak_refs (void);
+extern void rep_weak_refs_init (void);
+
 #ifdef rep_HAVE_UNIX
 
 /* from unix_dl.c */
